Backport of ``multiprocessing.shared_memory`` for Python 3.6 and 3.7. Simply import all things from ``shared_memory`` to make your code work. 

Note that ``multiprocessing.managers.SharedMemoryManager`` is also included under ``shared_memory`` package.
